@@ -14,6 +14,7 @@ import time
 import urllib
 import xml.etree.ElementTree as ET
 import boto3
+import json 
 
 from tornado import gen
 from tornado.httpclient import (
@@ -718,13 +719,13 @@ def _list_keys(context, key_prefix, delimiter):
     @gen.coroutine
     def _list_first_page():
         response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
-        print(response)
+        print(json.dumps(response))
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
         response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
-        print(response)
+        print(json.dumps(response))
 
         return _parse_list_response(response)
 
@@ -734,8 +735,8 @@ def _list_keys(context, key_prefix, delimiter):
         directories = []
         if 'Contents' in response:
             for item in response.Contents:
-                key = item.Contents.Key
-                last_modified_str = item.Contents.LastModified
+                key = item.Key
+                last_modified_str = item.LastModified
                 last_modified = datetime.datetime.strptime(
                     last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
                 keys.append((key, last_modified))
